@@ -13,6 +13,8 @@
 from __future__ import print_function
 
 import collections
+import fnmatch
+import logging
 import os.path
 import re
 import subprocess
@@ -21,6 +23,7 @@ import sys
 from reno import utils
 
 _TAG_PAT = re.compile('tag: ([\d\.]+)')
+LOG = logging.getLogger(__name__)
 
 
 def _get_current_version(reporoot, branch=None):
@@ -78,7 +81,6 @@ def _get_unique_id(filename):
 
 # TODO(dhellmann): Add branch arg?
 def get_notes_by_version(reporoot, notesdir, branch=None):
-
     """Return an OrderedDict mapping versions to lists of notes files.
 
     The versions are presented in reverse chronological order.
@@ -87,13 +89,15 @@ def get_notes_by_version(reporoot, notesdir, branch=None):
     they were available, regardless of whether they changed later.
     """
 
+    LOG.debug('scanning %s/%s (branch=%s)' % (reporoot, notesdir, branch))
+
     versions = []
     earliest_seen = collections.OrderedDict()
 
     # Determine the current version, which might be an unreleased or dev
     # version.
     current_version = _get_current_version(reporoot, branch)
-    # print('current_version = %s' % current_version)
+    LOG.debug('current repository version: %s' % current_version)
 
     # Remember the most current filename for each id, to allow for
     # renames.
@@ -104,7 +108,7 @@ def get_notes_by_version(reporoot, notesdir, branch=None):
     log_cmd = ['git', 'log', '--pretty=%x00%H %d', '--name-only']
     if branch is not None:
         log_cmd.append(branch)
-    log_cmd.extend(['--', notesdir + '/*.yaml'])
+    LOG.debug('running %s' % ' '.join(log_cmd))
     history_results = utils.check_output(log_cmd, cwd=reporoot)
     history = history_results.split('\x00')
     current_version = current_version
@@ -120,7 +124,18 @@ def get_notes_by_version(reporoot, notesdir, branch=None):
         # include tags, the other lines are filenames.
         sha = hlines[0].split(' ')[0]
         tags = _TAG_PAT.findall(hlines[0])
-        filenames = hlines[2:]
+        # Filter the files based on the notes directory we were
+        # given. We cannot do this in the git log command directly
+        # because it means we end up skipping some of the tags if the
+        # commits being tagged don't include any release note
+        # files. Even if this list ends up empty, we continue doing
+        # the other processing so that we record all of the known
+        # versions.
+        filenames = [
+            f
+            for f in hlines[2:]
+            if fnmatch.fnmatch(f, notesdir + '/*.yaml')
+        ]
 
         # If there are no tags in this block, assume the most recently
         # seen version.
@@ -128,27 +143,36 @@ def get_notes_by_version(reporoot, notesdir, branch=None):
             tags = [current_version]
         else:
             current_version = tags[0]
+            LOG.debug('%s has tags, updating current version to %s' %
+                      (sha, current_version))
 
         # Remember each version we have seen.
         if current_version not in versions:
+            LOG.debug('%s is a new version' % current_version)
             versions.append(current_version)
 
+        LOG.debug('%s contains files %s' % (sha, filenames))
+
         # Remember the files seen, using their UUID suffix as a unique id.
         for f in filenames:
             # Updated as older tags are found, handling edits to release
             # notes.
+            LOG.debug('setting earliest reference to %s to %s' %
+                      (f, tags[0]))
             uniqueid = _get_unique_id(f)
             earliest_seen[uniqueid] = tags[0]
             if uniqueid in last_name_by_id:
                 # We already have a filename for this id from a
                 # new commit, so use that one in case the name has
                 # changed.
+                LOG.debug('%s was seen before' % f)
                 continue
             if _file_exists_at_commit(reporoot, f, sha):
                 # Remember this filename as the most recent version of
                 # the unique id we have seen, in case the name
                 # changed from an older commit.
                 last_name_by_id[uniqueid] = (f, sha)
+                LOG.debug('remembering %s as filename for %s' % (f, uniqueid))
 
     # Invert earliest_seen to make a list of notes files for each
     # version.
@@ -170,7 +194,14 @@ def get_notes_by_version(reporoot, notesdir, branch=None):
                 uniqueid,
                 file=sys.stderr,
             )
-    for version, filenames in files_and_tags.items():
-        files_and_tags[version] = list(reversed(filenames))
 
-    return files_and_tags
+    # Only return the parts of files_and_tags that actually have
+    # filenames associated with the versions.
+    trimmed = {
+        k: list(reversed(v))
+        for (k, v)
+        in files_and_tags.items()
+        if v
+    }
+
+    return trimmed
